==> recipes_0.2.0.tar.gz: recipes/tests/testthat/_snaps/BoxCox.md <==
# simple Box Cox

    Code
      rec_trained <- prep(rec, training = ex_dat, verbose = FALSE)
    Warning <rlang_warning>
      Non-positive values in selected variable.
      Fewer than `num_unique` values in selected variable.
      No Box-Cox transformation could be estimated for: `x2`, `x3`

# printing

    Code
      rec
    Output
      Recipe
      
      Inputs:
      
            role #variables
       predictor          4
      
      Operations:
      
      Box-Cox transformation on x1, x2, x3, x4

---

    Code
      prep(rec, training = ex_dat)
    Warning <rlang_warning>
      Non-positive values in selected variable.
      Fewer than `num_unique` values in selected variable.
      No Box-Cox transformation could be estimated for: `x2`, `x3`
    Output
      Recipe
      
      Inputs:
      
            role #variables
       predictor          4
      
      Training data contained 20 data points and no missing data.
      
      Operations:
      
      Box-Cox transformation on x1, x4 [trained]

# empty printing

    Code
      rec
    Output
      Recipe
      
      Inputs:
      
            role #variables
         outcome          1
       predictor         10
      
      Operations:
      
      Box-Cox transformation on <none>

---

    Code
      rec
    Output
      Recipe
      
      Inputs:
      
            role #variables
         outcome          1
       predictor         10
      
      Training data contained 32 data points and no missing data.
      
      Operations:
      
      Box-Cox transformation on <none> [trained]

==> recipes_1.0.1.tar.gz: recipes/tests/testthat/_snaps/BoxCox.md <==
# simple Box Cox

    Code
      rec_trained <- prep(rec, training = ex_dat, verbose = FALSE)
    Condition
      Warning:
      Non-positive values in selected variable.
      Warning:
      Fewer than `num_unique` values in selected variable.
      Warning:
      No Box-Cox transformation could be estimated for: `x2`, `x3`

# printing

    Code
      print(rec)
    Output
      Recipe
      
      Inputs:
      
            role #variables
       predictor          4
      
      Operations:
      
      Box-Cox transformation on x1, x2, x3, x4

---

    Code
      prep(rec)
    Condition
      Warning:
      Non-positive values in selected variable.
      Warning:
      Fewer than `num_unique` values in selected variable.
      Warning:
      No Box-Cox transformation could be estimated for: `x2`, `x3`
    Output
      Recipe
      
      Inputs:
      
            role #variables
       predictor          4
      
      Training data contained 20 data points and no missing data.
      
      Operations:
      
      Box-Cox transformation on x1, x4 [trained]

# empty printing

    Code
      rec
    Output
      Recipe
      
      Inputs:
      
            role #variables
         outcome          1
       predictor         10
      
      Operations:
      
      Box-Cox transformation on <none>

---

    Code
      rec
    Output
      Recipe
      
      Inputs:
      
            role #variables
         outcome          1
       predictor         10
      
      Training data contained 32 data points and no missing data.
      
      Operations:
      
      Box-Cox transformation on <none> [trained]
